import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "iam-floyd", "0.57.0", __name__[0:-6], "iam-floyd@0.57.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
